@@ -1,10 +1,10 @@
 package Pcore::API::S3;
 
 use Pcore -class, -res, -const;
-use Pcore::Lib::Digest qw[sha256_hex hmac_sha256_bin hmac_sha256_hex];
-use Pcore::Lib::Scalar qw[is_ref];
-use Pcore::Lib::Data qw[to_uri_query from_xml];
-use Pcore::Lib::Term::Progress;
+use Pcore::Util::Digest qw[sha256_hex hmac_sha256_bin hmac_sha256_hex];
+use Pcore::Util::Scalar qw[is_ref];
+use Pcore::Util::Data qw[to_uri_query from_xml];
+use Pcore::Util::Term::Progress;
 use IO::Compress::Gzip qw[gzip];
 
 has key         => ();
@@ -390,7 +390,7 @@ sub sync ( $self, $locations, $tree ) {
 
         say 'Uploading files ...';
 
-        my $progress = Pcore::Lib::Term::Progress::get_indicator( network => 0, total => scalar $tree->{files}->%*, value => 0 );
+        my $progress = Pcore::Util::Term::Progress::get_indicator( network => 0, total => scalar $tree->{files}->%*, value => 0 );
 
         for my $file ( values $tree->{files}->%* ) {
             $cv->begin;
@@ -422,7 +422,7 @@ sub sync ( $self, $locations, $tree ) {
     if ( my @to_remove = grep { !exists $tree->{files}->{$_} } keys $remote_files->%* ) {
         say 'Removing files ...';
 
-        my $progress = Pcore::Lib::Term::Progress::get_indicator( network => 0, total => scalar @to_remove, value => 0 );
+        my $progress = Pcore::Util::Term::Progress::get_indicator( network => 0, total => scalar @to_remove, value => 0 );
 
         my $cv = P->cv->begin;
 
