@@ -1,11 +1,11 @@
 package Pcore::Handle::DBI::Query::SET;
 
 use Pcore -class;
-use Pcore::Lib::Scalar qw[is_ref is_plain_scalarref is_arrayref is_plain_hashref is_blessed_hashref];
+use Pcore::Util::Scalar qw[is_ref is_plain_scalarref is_arrayref is_plain_hashref is_blessed_hashref];
 
 has _buf => ( required => 1 );    # ArrayRef
 
-sub get_query ( $self, $dbh, $final, $i ) {
+sub GET_SQL_QUERY ( $self, $dbh, $i ) {
     my ( @sql, @bind );
 
     for my $token ( $self->{_buf}->@* ) {
@@ -47,7 +47,7 @@ sub get_query ( $self, $dbh, $final, $i ) {
 
                 # object
                 elsif ( is_blessed_hashref $token->{$field} ) {
-                    my ( $sql, $bind ) = $token->{$field}->get_query( $dbh, 0, $i );
+                    my ( $sql, $bind ) = $token->{$field}->GET_SQL_QUERY( $dbh, $i );
 
                     if ($sql) {
                         push @sql1, $dbh->quote_id($field) . ' = ' . $sql;
@@ -75,7 +75,7 @@ sub get_query ( $self, $dbh, $final, $i ) {
         return;
     }
     else {
-        return ( $final ? 'SET ' : $EMPTY ) . join( $SPACE, @sql ), \@bind;
+        return 'SET ' . join( $SPACE, @sql ), \@bind;
     }
 }
 
