@@ -23,8 +23,8 @@ export KILL_TIMEOUT=10
 
 export DOCKER_CONTAINER_ARGS="
     -v $SCRIPT_DIR:/var/local/$NAME/data \
+    -v /var/run/nginx:/var/run/nginx \
     -p 80:80/tcp \
-    -p 443:443/tcp \
     --shm-size=1g \
 "
 
